<?php

namespace App\Controller\Sub;

use App\Connexion;
use App\Controller\VisitorController;
use App\Data\TacticInfo;
use App\Gateway\TacticInfoGateway;
use App\Http\HttpCodes;
use App\Http\HttpResponse;
use App\Http\JsonHttpResponse;
use App\Http\ViewHttpResponse;
use App\Model\TacticModel;
use App\Session\SessionHandle;
use App\Validation\ValidationFail;
use App\Validator\TacticValidator;

class EditorController {
    private TacticModel $model;

    public function __construct(TacticModel $model) {
        $this->model = $model;
    }

    private function openEditor(TacticInfo $tactic): HttpResponse {
        return ViewHttpResponse::react("views/Editor.tsx", ["name" => $tactic->getName(), "id" => $tactic->getId()]);
    }

    public function createNew(SessionHandle $session): HttpResponse {
        $tactic = $this->model->makeNewDefault($session->getAccount()->getId());
        return $this->openEditor($tactic);
    }

    /**
     * returns an editor view for a given tactic
     * @param int $id the targeted tactic identifier
     * @param SessionHandle $session
     * @return HttpResponse
     */
    public function edit(int $id, SessionHandle $session): HttpResponse {
        $tactic = $this->model->get($id);

        $failure = TacticValidator::validateAccess($tactic, $id, $session->getAccount()->getId());

        if ($failure != null) {
            return ViewHttpResponse::twig('error.html.twig', ['failures' => [$failure]], HttpCodes::NOT_FOUND);
        }

        return $this->openEditor($tactic);
    }


}
